@@ -213,7 +213,7 @@ class Frame:
         :return: A string representing this frame object
         :rtype: str
         """
-        return "<Frame %3d: %s>" % (self.__id, self.__msg.summary())
+        return "<Frame %3d: %s>" % (self.__id , self.__msg.summary())
 
     @property
     def timestamp(self):
@@ -411,8 +411,8 @@ class Frame:
             item: either(is_protocol, str)
     ) -> either(int, float, optional(Exception), str, is_layer_value):
         """
-        Get the requested informations of the layer level for this frame. This
-        function is also used to retrieve flat informations like src, dst, ...
+        Get the requested information of the layer level for this frame. This
+        function is also used to retrieve flat information like src, dst, ...
 
         :param prot: The layer level or information that we want to retrieve
         :type prot: either(type, str)
@@ -919,7 +919,7 @@ class Capture:
         :raises TypeError: If protocol is not a protocol class
         :raises ReaderError: If the reader couldn't process the file
 
-        :return: Basic informations about frames like the underlying example
+        :return: Basic information about frames like the underlying example
         :rtype: [(int, str)]
 
         :Example:
